@@ -157,9 +157,8 @@ class ProjectApps(Controller):
         project_app = self.app.client.get_project_app(p_id, pa_id)
         if response.is_succeed:
             if self.app.pargs.deploy:
-                self.app.client.deploy_project_app_with_autolatest(
-                    project_id=p_id, project_app_id=pa_id
-                )
+                current_deployment_tag = {'tag': project_app.data['current_deployment']['version']}
+                self.app.client.deploy_project_app(p_id, pa_id, data=current_deployment_tag)
 
             row = response.data
             row['env'] = ''
@@ -206,9 +205,8 @@ class ProjectApps(Controller):
 
         if response.is_succeed:
             if self.app.pargs.deploy:
-                self.app.client.deploy_project_app_with_autolatest(
-                    project_id=p_id, project_app_id=pa_id
-                )
+                current_deployment_tag = {'tag': project_app.data['current_deployment']['version']}
+                self.app.client.deploy_project_app(p_id, pa_id, data=current_deployment_tag)
 
             row = response.data
             row['env'] = ''
@@ -319,58 +317,6 @@ class ProjectApps(Controller):
         else:
             self.app.render({}, renderer_type='text', custom_text=response.data["non_field_errors"])
 
-    @ex(
-        help='Deploy Project App With Stable Version',
-        arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['project_app_id'], {
-                'help': 'Project App ID',
-                'action': 'store',
-            }),
-        ],
-    )
-    def deploy_stable(self):
-        project_id = self.app.pargs.project_id
-        project_app_id = self.app.pargs.project_app_id
-
-        response = self.app.client.deploy_project_app_with_stable_version(
-            project_id=project_id, project_app_id=project_app_id
-        )
-    
-        if response.is_succeed:
-            self.app.render({}, renderer_type='text', custom_text="ProjectApp deployment has been started with the stable version.")
-        else:
-            self.app.render({}, renderer_type='text', custom_text=response.data['non_field_errors'])
-
-    @ex(
-        help='Deploy Project App With Last Completed Deployment',
-        arguments=[
-            (['project_id'], {
-                'help': 'Project ID',
-                'action': 'store',
-            }),
-            (['project_app_id'], {
-                'help': 'Project App ID',
-                'action': 'store',
-            }),
-        ],
-    )
-    def redeploy(self):
-        project_id = self.app.pargs.project_id
-        project_app_id = self.app.pargs.project_app_id
-
-        response = self.app.client.deploy_project_app_with_autolatest(
-            project_id=project_id, project_app_id=project_app_id
-        )
-    
-        if response.is_succeed:
-            self.app.render({}, renderer_type='text', custom_text="ProjectApp deployment has been started with the last completed deployment.")
-        else:
-            self.app.render({}, renderer_type='text', custom_text=response.data['non_field_errors'])
-
     @ex(
         help='Project App Deployment List Command',
         arguments=[
